# pygal_maps_ru  

Russian maps for Pygal

## Usage

~~~~
import pygal.maps.ru

map = pygal.maps.ru.Regions()
map.add('Data', {'KHM': 2, 'KYA': 5})
map.render_to_file('test.svg')

~~~~

## Requirements

* [Pygal](https://github.com/Kozea/pygal) 

## Author
[burevol](https://github.com/burevol)   
SVG map by [SmartTeleMax](https://github.com/SmartTeleMax)
